pro Set_Windows_Device
;
;  this procedure selects the output MS Windows device according
;  to the value of plotdev:
;
;     plotdev = 'win' for default size (1/4 screen) on-screen output to MS Windows
;             = 'big' for large size (full screen) on-screen output to MS Windows
;                for high resolution conversion to a png or jpeg files
;             = 'null' to skip generating a plot of any kind
;
;     scale rescales the default plot size; normal is 1
;
;  select the monitor resolution

;  for 1024 x 768 use
;  xwin = 512
;  ywin = 384
;  xbig = 950
;  ybig = 700

;  for 1280 x 1024 use
  xwin = 640
  ywin = 512
  xbig = 1200
  ybig = 900

scale = 1.0

print," select plot device (win or big)"
plotdev = ' '
read,plotdev

;  remove any leading or trailing blanks and check plotdev

plotdev = strtrim(plotdev,2)
if (plotdev ne 'win' and plotdev ne 'big' and $
    plotdev ne 'null') then begin
    print,' requested plot device ',plotdev,' is not allowed'
    return
endif

case 1 of

(plotdev eq 'win'): begin

   set_plot,'win'
   ; settings for default Windows display.
   ; the default window is 1/4 of the screen
   window,xsize=xwin,ysize=ywin

   device,decomposed=0 ; for true color display settings

   ;  set for black plot on white background (can override)

 ;  !p.background=255
   !p.color=0
   ; set scale = 0 to get proper windows plot (why this
   ;               works I don't know, but it does)
 ;  scale = 0

; default settings for best appearance on the screen
; (can override in the calling program)
!p.charsize = 1.25
!p.thick = 2.0
!p.charthick = 1.5
!x.margin = [10.,4.]
!y.margin = [4.,4.]

end

(plotdev eq 'big'): begin

   ; settings for MS Windows display, with a big window to give
   ; higher resolution for creation of png or jpeg files

   set_plot,'win'
   ;  set for black plot on white background
;   !p.background=255
   !p.color=0
   ; make a big window (almost full screen)
   window,xsize=xbig,ysize=ybig

   device,decomposed=0 ; for true color display settings

   scale = 1.5

; default settings for best appearance on the screen
; (can override in the calling program)
!p.charsize = 3.5
!p.thick = 2.0
!p.charthick = 2.0
!x.margin = [10.,4.]
!y.margin = [4.,4.]

end

(plotdev eq 'null'): begin
   ; do not generate a plot
   set_plot,'null'
end

endcase

;
return
end

