@read_H_Lfile
@set_Windows_device
@LUTcolor

pro plot_L_z
;
;     This routine plots radiance as a function of depth for seleted directions and one wavelength
;
;     The input file fndata is a HYDROLIGHT 5.0 "Lroot.txt" digital output file, which
;     contains the total radiance L(depth,theta,phi,wavelength)
;
;       one free-format input record read from the keyboard to override the
;          default y axis range and scaling, if desired

;  the common blocks give access to all data read from a Lroot.txt file

;  This common block is for use ONLY with HYDROLIGHT L files
common cLdata, nz,ntheta,nphi,nwave,depth,theta,phi,wavelength,radiance

; radiance = fltarr(nz,ntheta,nphi,nwave); depth index 0 is in-air; depth index 1 is in water at depth 0
; depth = fltarr(nz); depth(0) = -1.0 for air; depth(1) = 0.0 for in water
;
;
;  ***** read in all data from the HydroLight Droot.txt file
;
dirname = '.\'  ; directory where to look first

Lfilename = dialog_pickfile(path=dirname,filter=['L*.txt'],title='Select the HydroLight Lroot.txt file')

; read the entire Droot.txt file.  Information comes back via the common blocks.

read_H_Lfile,Lfilename ; to read a HYDROLIGHT Lroot.txt file

;
;  select output device
;
set_Windows_device
!x.margin = [8,4]
!y.margin = [4,3]

;  ***** Set up the colors to be used in the plot ---------------
;
; load a color table
LUTcolor
!p.background=11
;
;  plot the array
;
ymin = -1.0
ymax = -1.0
arrmax = max(radiance,min=arrmin)
if ymin lt 0.0 then ymin = arrmin
if ymax lt 0.0 then ymax = arrmax
;
;  draw and label first curve
;
ylabel = 'depth !8z!x (m)'
xlabel = 'radiance !8L!x (W m!u-2!n sr!u-1!n nm!u-1!n)'

; indices
indxw = [20]
print,' wavelength = ',wavelength[indxw[0]]



xmin = 1.0e-5
xmax = 1.0
toptitl = 'selected radiances at 555 nm'
;
plot_oi,radiance[1:nz-1,0,0,indxw[0]],depth[1:nz-1],  $
;plot_io,wavel,Rrs, $
   title=toptitl,  $
     xrange=[xmin,xmax], /xstyle, xtitle = xlabel, $ ;xticks=4, xminor=1,
   xtickname = xticklab, $
   yrange=[50,0.0],  ytitle = ylabel, $
   linestyle=0,thick=2.0,color=0,charsize=3.5; ,/nodata

; create a plot with color-coded directions

; radiance(*,0,0,wl) is the zenith-viewing rad L_d
; radiance(*,ntheta-1,0,wl) is the nadir-viewing rad L_u
; 0.5*(radiance[1:nz-1,9,0,indxw[0]] + radiance[1:nz-1,10,0,indxw[0]]) is horizontal, looking toward the sun (photons traveling in phi = 0, phi index 0)
; 0.5*(radiance[1:nz-1,9,6,indxw[0]] + radiance[1:nz-1,10,6,indxw[0]]) is horizontal, looking perp to the sun (phi = 90, phi index 6
; 0.5*(radiance[1:nz-1,9,12,indxw[0]] + radiance[1:nz-1,10,12,indxw[0]]) is horizontal, looking away from the sun (phi = 180, phi index 12)

iw = indxw[0]
thck = 4
oplot,radiance[1:nz-1,0,0,indxw[0]],depth[1:nz-1],thick=thck,color=1
oplot,radiance[1:nz-1,ntheta-1,0,indxw[0]],depth[1:nz-1],thick=thck,color=2
oplot,0.5*(radiance[1:nz-1,9,0,indxw[0]] + radiance[1:nz-1,10,0,indxw[0]]),depth[1:nz-1],thick=thck,color=3
oplot,0.5*(radiance[1:nz-1,9,6,indxw[0]] + radiance[1:nz-1,10,6,indxw[0]]),depth[1:nz-1],thick=thck,color=4
oplot,0.5*(radiance[1:nz-1,9,12,indxw[0]] + radiance[1:nz-1,10,12,indxw[0]]),depth[1:nz-1],thick=thck,color=8



; add labels

csize = 3.0
xval = 0.18
yval = 0.84
dy = 0.05
xyouts,xval,yval,'!8L!dd!n!x, zenith-viewing',charsize=csize, color=1, /normal
xyouts,xval,yval-dy,'!8L!du!n!x, nadir-viewing',charsize=csize, color=2, /normal
xyouts,xval,yval-2*dy,'!8L!dh!n!x, toward sun',charsize=csize, color=8, /normal
xyouts,xval,yval-3*dy,'!8L!dh!n!x, perp. to sun',charsize=csize, color=4, /normal
xyouts,xval,yval-4*dy,'!8L!dh!n!x, away from sun',charsize=csize, color=3, /normal


print,'end plot_Lzw'
end


