@read_H_Lfile
@set_Windows_device
@spectrum

pro plot_L_z_lambda
;
;     Example IDL user routine on file IDL\HE5UG_Fig8.pro
;
;     This routine generated figs 8 and 12 of the Hydrolight 5 Users' Guide
;
;     This program plots the nadir-viewing remote-sensing reflectance Rrs as a
;     function of wavelength.
;
;     The input files are a Hydrolight "Droot.txt" digital output
;     file as written by maincode\savedata.f, and a an Ecolight Droot file
;
;       one free-format input record read from the keyboard to override the
;          default y axis range and scaling, if desired

;     This routine plots radiance as a function of depth for seleted directions and one wavelength
;
;     The input file fndata is a HYDROLIGHT 5.0 "Lroot.txt" digital output file, which
;     contains the total radiance L(depth,theta,phi,wavelength)
;
;       one free-format input record read from the keyboard to override the
;          default y axis range and scaling, if desired

;  the common blocks give access to all data read from a Lroot.txt file

;  This common block is for use ONLY with HYDROLIGHT L files
common cLdata, nz,ntheta,nphi,nwave,depth,theta,phi,wavelength,radiance

; radiance = fltarr(nz,ntheta,nphi,nwave);
;            depth index 0 is in-air; depth index 1 is in water at depth 0
;            itheta = 0 and jphi = 0 is Ld, itheta = ntheta-1 and jphi = 0 is Lu
; depth = fltarr(nz); depth(0) = -1.0 for air; depth(1) = 0.0 for in water
;
;
;  ***** read in all data from the HydroLight Droot.txt file
;
dirname = '.\'  ; directory where to look first

Lfilename = dialog_pickfile(path=dirname,filter=['L*.txt'],title='Select the HydroLight Lroot.txt file')

; read the entire Droot.txt file.  Information comes back via the common blocks.

read_H_Lfile,Lfilename ; to read a HYDROLIGHT Lroot.txt file

;
;  select output device
;
set_Windows_device
!x.margin = [9,6]
!y.margin = [4,3]

;  ***** Set up the colors to be used in the plot ---------------
;
; load a spectrum color table
spectrum  ;a color table with 225 colors from 350-800 nm

!p.background = 227
;
;  plot the array
;
ymin = -1.0
ymax = -1.0
arrmax = max(radiance(0,ntheta-1,0,*),min=arrmin)
if ymin lt 0.0 then ymin = arrmin
if ymax lt 0.0 then ymax = arrmax
;
;  draw and label first curve
;
xlabel = 'wavelength !7k!x (nm)'
xticklab = [' ','400',' ','500',' ','600',' ','700',' ']
ylabel = '!8L!x!dd!n (W m!u-2!n sr!u-1!n nm!u-1!n)'

;depth indices
indxz = [0,1,11,17,22,27,32]
itheta = ntheta-1 ; for Lu
itheta = 0; for Ld
print,'radiance(0,ntheta-1,0,0) = ',radiance(0,ntheta-1,0,0)
print,'radiance(0,0,0,0) = ',radiance(0,0,0,0)
print,'radiance(1,ntheta-1,0,0) = ',radiance(1,ntheta-1,0,0)
print,'radiance(1,0,0,0) = ',radiance(1,0,0,0)

ymin = 1.0e-11
ymax = 1
if itheta eq 0 then toptitl = 'downwelling radiance at selected depths'
if itheta eq ntheta-1 then toptitl = 'upwelling radiance at selected depths'
;
plot_io,wavelength,radiance(0,itheta,0,*),  $
;plot_io,wavel,Rrs, $
   title=toptitl,  $
    xrange=[350.,700.], xticks=7, xminor=5, /xstyle, xtitle = xlabel, $
   xtickname = xticklab, $
   yrange=[ymin,ymax],  ytitle = ylabel,/ystyle, $
   linestyle=0,thick=4.0,color=0,charsize=3.5;,/nodata

; create a plot with color-coded wavelengths

for iz = 1,n_elements(indxz)-1 do begin
kz = indxz(iz)

for iw=0,nwave-2 do begin

   kolor = fix((wavelength(iw) - 350.0)/2.0)
   oplot,[wavelength[iw],wavelength[iw+1]],[radiance(kz,itheta,0,iw),radiance(kz,itheta,0,iw+1)],color=kolor,thick=4

; overplot the inwater data


  ; oplot,[wavel[iw],wavel[iw+1]],[Lu_water[nmu-1,indxz[iz],iw],Lu_water[nmu-1,indxz[iz],iw+1]],color=kolor,thick=4

endfor
endfor

; overplot the in-air spectrum
;oplot,wavel,Lu_air(nmu-1,*),color=0,thick=1

; add depth labels at the right

csize = 3.0
xval = 705.0
xyouts,xval,0.5*ymax,'depth',charsize=csize
xyouts,xval,radiance(0,itheta,0,nwave-1),'in air',charsize=csize

for iz = 1,n_elements(indxz)-1 do begin
kz = indxz(iz)
   zlabel = string(depth[indxz[iz]],format='(i3)') + ' m'
   xyouts,xval,radiance(kz,itheta,0,nwave-1),zlabel,charsize=csize

endfor

print,'end plot_L_z_lambda'
end


