pro Set_Output_Device,plotdev

;
;  this procedure selects the plot output device according to the value of plotdev:
;
;     plotdev = 'win' for default size (1/4 screen) on-screen output to MS Windows
;             = 'big' for large size (full screen) on-screen output to MS Windows
;                for high resolution conversion to a png or jpeg files
;            = 'eps' to generate a eps output file (not plotted on screen)
;             = 'null' to skip generating a plot of any kind
;
;     scale rescales the default plot size; normal is 1
;
;  select the monitor resolution for Windows plots

;  for 1024 x 768 use
;  xwin = 512
;  ywin = 384
;  xbig = 950
;  ybig = 700

;  for 1280 x 1024 use
  xwin = 640
  ywin = 512
  xbig = 1200
  ybig = 900

scale = 1.0

print," select plot device (win, big, or eps)"
plotdev = ' '
read,plotdev

;  remove any leading or trailing blanks and check plotdev

plotdev = strtrim(plotdev,2)
if (plotdev ne 'win' and plotdev ne 'big' and $
    plotdev ne 'eps' and plotdev ne 'null') then begin
    print,' requested plot device ',plotdev,' is not allowed'
    return
endif

case 1 of

(plotdev eq 'win'): begin

   set_plot,'win'
   ; settings for default Windows display.
   ; the default window is 1/4 of the screen
   window,xsize=xwin,ysize=ywin

   device,decomposed=0 ; for true color display settings

   ;  set for black plot on white background (can override)

 ;  !p.background=255
   !p.color=0
   ; set scale = 0 to get proper windows plot (why this
   ;               works I don't know, but it does)
 ;  scale = 0

; default settings for best appearance on the screen
; (can override in the calling program)
!p.charsize = 1.25
!p.thick = 2.0
!p.charthick = 1.5
!x.margin = [10.,4.]
!y.margin = [4.,4.]

end

(plotdev eq 'big'): begin

   ; settings for MS Windows display, with a big window to give
   ; higher resolution for creation of png or jpeg files

   set_plot,'win'
   ;  set for black plot on white background
;   !p.background=255
   !p.color=0
   ; make a big window (almost full screen)
   window,xsize=xbig,ysize=ybig

   device,decomposed=0 ; for true color display settings

   scale = 1.5

; default settings for best appearance on the screen
; (can override in the calling program)
!p.charsize = 3.5
!p.thick = 2.0
!p.charthick = 2.0
!x.margin = [10.,4.]
!y.margin = [4.,4.]
end

(plotdev eq 'eps'): begin

; This option generates an eps file for inportation into wordprocessors, etc.  The plot is not desplayed on screen.

set_plot,'PS'
device, color=1, bits_per_pixel=8
device, /Encapsulated

epsfilename = '  '
print,'Enter the name of the eps file.  ".eps" will be appended to the file name.
read,epsfilename
epsfilename = strtrim(epsfilename,2) + '.eps'
print,' The eps file will be created in the current directory and named  ',epsfilename
device, Filename=epsfilename
!x.margin = [10.,2.5]
!y.margin = [3.5,1.5]
!p.charsize = 1.75
!p.charthick = 2.0
;!p.font = -1 ; 1 for TrueType fonts
title = '!6'

end

(plotdev eq 'null'): begin
   ; do not generate a plot
   set_plot,'null'
end

endcase

;
return
end

