pro spectrum
;
; This procedure sets up a Red-Green-Blue color table for use
; in generating color plots, using the "color" keyword in
; the plot or oplot routine to select the color.
;
; There are 226 colors, which cover the 350-800 nm spectrum used
; in Hydrolight at 2 nm spacing.  The color table maps the 350-800 nm
; range with colors roughly resembling the spectrum:
;
; wavelength index  color
; 350          0    black, for use with axes, etc
; 400         25    violet
; 476         50    blue
; 510         80    green
; 576        113    yellow
; 590        120    orange
; 650        150    red
; 800        225    black
; ---        226    white, for use as the background color
; ---        235    black, with a gray scale from 226 to 235
; (note that IDL usually has 235 colors available out of the 256 colors available in Windows)
;
; the color table index corresponding to a given wavelength can
; be computed as index = fix((wavelength - 350.)/2.0)
;
; read the file with the r,g,b values
r = intarr(236,/nozero)
g = intarr(236,/nozero)
b = intarr(236,/nozero)
openr,50,'spectrgb.txt'
header = ' '
readf,50,header
for i=0,235 do begin
   readf,50,rr,gr,br
   r(i) = rr
   g(i) = gr
   b(i) = br
endfor
close,50

; load the new color table for use in plotting

tvlct,r,g,b

; set the foreground (black) and background (white) colors
!p.color = 235
!p.background = 226

return
end
